/**
* This file is part of ArmarX.
*
* ArmarX is free software; you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2 of
* the License, or (at your option) any later version.
*
* ArmarX is distributed in the hope that it will be useful, but
* WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @package    Armar4::api
* @author     Nikolaus Vahrenkamp
* @date       2012 Nikolaus Vahrenkamp
* @copyright  http://www.gnu.org/licenses/gpl.txt
*             GNU General Public License
*/

#include <Core/core/Component.h>
#include <Core/core/system/ImportExportComponent.h>
#include <Core/statechart/Statechart.h>
#include <Core/robotstate/remote/RemoteRobot.h>
#include <Core/robotstate/remote/ArmarPose.h>
#include <Core/robotstate/RobotStateObjectFactories.h>


//#include <VirtualRobot/VirtualRobot.h>

#include "RobotStatechartContext.h"

namespace armarx
{
    // ****************************************************************
    // Implementation of Component
    // ****************************************************************
    void RobotStatechartContext::onInitComponent()
    {
        StatechartContext::onInitComponent();
        ARMARX_LOG << eINFO << "Init Armar4Context" << flush;

        RobotStateObjectFactories::addFactories(getIceManager()->getCommunicator());
        kinematicUnitObserverName = getProperty<std::string>("KinematicUnitObserverName").getValue();


        usingProxy("RobotStateComponent");
        usingProxy(kinematicUnitObserverName);
    }


    void RobotStatechartContext::onConnectComponent()
    {
        StatechartContext::onConnectComponent();
        ARMARX_LOG << eINFO << "Starting Armar4Context" << flush;

        // retrieve proxies
        robotStateComponent = getProxy<RobotStateComponentInterfacePrx>("RobotStateComponent");
        kinematicUnitPrx = getProxy<KinematicUnitInterfacePrx>(getProperty<std::string>("KinematicUnitName").getValue());
        kinematicUnitObserverPrx = getProxy<KinematicUnitObserverInterfacePrx>(kinematicUnitObserverName);
        ARMARX_LOG << eINFO << "Fetched proxies" <<  kinematicUnitPrx << " " << robotStateComponent << flush;

		// initialize remote robot	
        remoteRobot.reset(new RemoteRobot(robotStateComponent->getSynchronizedRobot()));
        ARMARX_LOG << eINFO << "Created remote robot" << flush;
    }

    PropertyDefinitionsPtr RobotStatechartContext::createPropertyDefinitions()
    {
        return PropertyDefinitionsPtr(new RobotStatechartContextProperties(
                                               getConfigIdentifier()));
    }

   /* const VirtualRobot::RobotPtr armarx::Armar4Context::getRobot()
    {
        return remoteRobot;
    }*/

}

